@@ -1,4 +1,5 @@
 import argparse
+import json
 
 from azureml.core import Dataset, Run
 from chunk_files import chunk_files
@@ -6,8 +7,7 @@ import shutil
 
 # Get parameters
 parser = argparse.ArgumentParser()
-parser.add_argument("--dataset_name", type=str, help="Dataset name")
-parser.add_argument("--dataset_version", type=str, help="Dataset version")
+parser.add_argument("--datasets_json", type=str, help="Dataset json")
 parser.add_argument(
     "--raw_data_dir", type=str, help="Directory to store raw pdf,png,jpeg,tiff"
 )
@@ -16,8 +16,7 @@ parser.add_argument("--chunk_index", type=int, help="Chunk index")
 
 # Get arguments from parser
 args = parser.parse_args()
-dataset_name = args.dataset_name
-dataset_version = args.dataset_version
+datasets = json.load(args.datasets_json)
 raw_data_dir = args.raw_data_dir
 number_chunk = args.number_chunk
 chunk_index = args.chunk_index
@@ -27,13 +26,15 @@ run = Run.get_context()
 workspace = run.experiment.workspace
 
 # Get raw data
-raw_dataset = Dataset.get_by_name(workspace, dataset_name, version=dataset_version)
-print(
-    f"Retrieve raw data in dataset: {raw_dataset.name} - version: {raw_dataset.version}"
-)
-
-raw_dataset.as_mount("/mnt/input_data")
-
-chunk_files(raw_dataset, raw_data_dir, number_chunk, shutil.copy, [chunk_index])
+for dataset in datasets:
+    dataset_name = dataset["name"]
+    dataset_version = dataset["version"]
+    dataset_directory = dataset["directory"]
+    raw_dataset = Dataset.get_by_name(workspace, dataset_name, version=dataset_version)
+    print(
+        f"Retrieve raw data in dataset: {raw_dataset.name} - version: {raw_dataset.version}"
+    )
+    raw_dataset.as_mount("/mnt/input_data")
+    chunk_files(raw_dataset, raw_data_dir, number_chunk, shutil.copy, [chunk_index], dataset_directory)
 
 
